#
# Cookbook:: pf_chef_wrapper_nagios_server
# Recipe:: default
#
# Copyright:: 2018, PubFactory, All Rights Reserved.

## Common Data ##

include_recipe 'pf_chef_wrapper_nagios_server::commands'
include_recipe 'pf_chef_wrapper_nagios_server::contacts'
include_recipe 'pf_chef_wrapper_nagios_server::contactgroups'
include_recipe 'pf_chef_wrapper_nagios_server::hosts'
include_recipe 'pf_chef_wrapper_nagios_server::hostgroups'
include_recipe 'pf_chef_wrapper_nagios_server::resources'
include_recipe 'pf_chef_wrapper_nagios_server::services'
include_recipe 'pf_chef_wrapper_nagios_server::timeperiods'

node['pf_chef_wrapper_nagios_server']['monitor_sites'].each do |site|
	next if site == 'manual'
	node_list = search(:node, "tags:site_#{site} AND -chef_environment:_default")

	unless node_list.empty?
		include_recipe "pf_chef_wrapper_nagios_server::site_#{site}"

		environment_list = node_list.map { |node| node.chef_environment }.uniq
		environment_list.each do |environment|
			environment_members = node_list.select { |node| node.chef_environment == environment }.map { |node| node.name }
			nagios_hostgroup "#{environment}_#{site}" do
				options 'members' => environment_members
			end
		end

		nagios_hostgroup "site_#{site}" do
			options 'hostgroup_members' => environment_list.map { |environment| "#{environment}_#{site}" }
		end

		node_list.each do |node|

			nagios_host node.name do
				options 'use' => 'generic-host',
					'host_name' => node.name,
					'contact_groups' => 'ops,cs_escalation'
			end
		end

		group_list = node_list.collect_concat { |node| node['tags'].select { |tag| tag =~ /^group_.*$/ } }.uniq.map { |group| group.sub(/^group_/,'') }
		unless group_list.empty?
			group_list.each do |group|
				group_members = node_list.select { |node| node['tags'].select { |tag| tag == "group_#{group}" }.count > 0 }.map { |node| node.name }
				nagios_hostgroup group do
					options 'members' => group_members
				end
				include_recipe "pf_chef_wrapper_nagios_server::group_#{group}"
			end
		end
	end
end

## Manual Hosts ##
if node['pf_chef_wrapper_nagios_server']['monitor_sites'].include? 'manual'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams-auth-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams-auth-02.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams.degruyter.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams.elibrary.imf.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams.hup.harvard.edu'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams-jobs.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams-psy-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams-psy-02.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams-web-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams-web-02.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_anb.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_berghahnjournals.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_bioscientifica.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_bloomsburyprofessionalonline.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_brill.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_content-ams-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_content-mgmt-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_contentstore.staywell.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_content-web-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_daredictionary.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_degruyter.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_dg-db-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_dg-db-02.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_dg-mlo-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_dg-mlo-02.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver1757.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2178.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2282.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2283.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2284.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2554.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2564.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2565.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2566.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2567.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2568.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2569.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2570.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_edgewebserver2571.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_elgaronline.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_elibrary.imf.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ewhserver1758.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ewhserver2180.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ewhserver2181.edgewebhosting.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_jms-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_jnccn.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_journals.ashs.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_journals.humankinetics.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_jurabibliotek.dk'
	include_recipe 'pf_chef_wrapper_nagios_server::host_lb-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_lb-02.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_loebclassics.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_manchesterhive.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_mgmt-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_null'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oed.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_opil.ouplaw.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordaasc.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordartonline.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordbiblicalstudies.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordbibliographies.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxforddnb.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordhandbooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordindex.oup.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordislamicstudies.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordmedicine.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordmusiconline.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordreference.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordscholarlyeditions.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordscholarship.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordwesternmusic.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_pdf-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_peterlang.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_pubfactory.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_sciendo.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_sipriyearbook.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_staging.daredictionary.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_test-ams-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_test-ams-02.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_test-ams-jobs.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_test-jms.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_test-mgmt-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_test-pdf-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_test-web-01.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_test-web-02.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_thejns.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ukwhoswho.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_universitypressscholarship.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_veryshortintroductions.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_web-10.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_web-11.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_web-13.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_web-15.dg.safaribooks.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_www.openbooks.crossknowledge.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_nfs-01.dg.pubfactory.net'
	include_recipe 'pf_chef_wrapper_nagios_server::host_new.degruyter.com'
end

## This is a hack! Don't use it unless you really have to
if node['pf_chef_wrapper_nagios_server']['monitor_sites'].include? 'manual-irl'
	include_recipe 'pf_chef_wrapper_nagios_server::manual_irl'
end

## Run nagios setup ##

include_recipe 'nagios::default'

## Add slack integration

package 'libwww-perl'
package 'libcrypt-ssleay-perl'

cookbook_file '/usr/local/bin/slack_nagios.pl' do
	source 'slack_nagios.pl'
	owner 'root'
	group 'root'
	mode '0755'
	action :create
end

##
# Need pip3 installed and libraries
# sudo apt install python3-pip
# pip3 install nagiosplugin
# pip3 install flatten_json

cookbook_file '/usr/local/bin/health_check.py' do
	source 'health_check.py'
	owner 'root'
	group 'root'
	mode '0755'
	action :create
end

## Don't use internal authentication ##

edit_resource(:template, '/etc/apache2/sites-available/nagios.conf') do
	source 'apache2.conf.erb'
	cookbook 'pf_chef_wrapper_nagios_server'
end
