nagios_host 'sciendo.com' do
	options 'use' => 'noping-host-https',
		'alias' => 'DGSG - Sciendo',
		'address' => 'content.sciendo.com',
		'contact_groups' => 'cs_email_only,DGSG',
		'notes' => 'DGSG - Sciendo Live Sites',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/DGSG/pages/175078636/Server+Setup+-+De+Gruyter+Second+Generation+DGSG'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# Checks the homepage of the live sciendo site and checks for the string 'Sciendo'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'sciendo.com-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'sciendo.com',
		'contact_groups' => 'cs_escalation,DGSG',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!dgsg:dgsg2017!/!Sciendo!10!20!',
		'notes' => 'DGSG - Sciendo Live Site',
		'notes_url' => 'https://content.sciendo.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# Checks the homepage of the live dgsg site on the first web node and checks for the string 'Sciendo'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'sciendo.com-Live Homepage: tomcat-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'sciendo.com',
		'display_name' => 'Live Homepage: tomcat-1',
		'check_command' => 'https_content_check_basic_auth_single_node!dgsg:dgsg2017!/!Sciendo!10!20!dgsg-web-live-1!tomcat-1!',
		'contact_groups' => 'admins_email_only,DGSG',
		'notes' => 'DGSG - Sciendo Live Site: tomcat-1',
		'notes_url' => 'https://content.sciendo.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# Checks the homepage of the live dgsg site on the second web node and checks for the string 'Sciendo'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'sciendo.com-Live Homepage: tomcat-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'sciendo.com',
		'display_name' => 'Live Homepage: tomcat-3',
		'check_command' => 'https_content_check_basic_auth_single_node!dgsg:dgsg2017!/!Sciendo!10!20!dgsg-web-live-3!tomcat-3!',
		'contact_groups' => 'admins_email_only,DGSG',
		'notes' => 'DGSG - Sciendo Live Site: tomcat-3',
		'notes_url' => 'https://content.sciendo.com/'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search page of the live dgsg site and checks for the string 'Browse'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'sciendo.com-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'sciendo.com',
		'display_name' => 'Live Search',
		'contact_groups' => 'cs_escalation,DGSG',
		'check_command' => 'https_content_check_basic_auth!dgsg:dgsg2017!/browse?level=parent!Browse!10!20!',
		'notes' => 'DGSG - Sciendo Live Site',
		'notes_url' => 'https://content.sciendo.com/browse?level=parent'
end
#------------------------------------------------------------------------------------
# VIEW
# Checks a content view page of the live dgsg site for the book at the URL
# /view/journals/mik/mik-overview.xml.  The title of this journal is "Art History".  This check looks for the string 'Haemophilia' in the
# response.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'sciendo.com-Live Content View' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'sciendo.com',
		'display_name' => 'Live Content View',
		'contact_groups' => 'cs_escalation,DGSG',
		'check_command' => 'https_content_check_basic_auth!dgsg:dgsg2017!/view/journals/mik/mik-overview.xml!"Art History"!10!20!',
		'notes' => 'DGSG - Sciendo Live Site',
		'notes_url' => 'https://content.sciendo.com/view/journals/mik/mik-overview.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Production Management Portal'
# in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'sciendo.com-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'sciendo.com',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.sciendo.com!/login!dgsg:dgsg2017!"Production Management Portal"!20!10',
		'contact_groups' => 'admins_email_only,DGSG',
		'notes' => 'DGSG - Sciendo Live Loader',
		'notes_url' => 'https://admin.sciendo.com/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Sciendo' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'sciendo.com-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'sciendo.com',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging.sciendo.com!dgsg:dgsg2017!Sciendo!20!10',
		'contact_groups' => 'admins_email_only,DGSG',
		'notes' => 'DGSG - Sciendo Staging Site',
		'notes_url' => 'https://staging.sciendo.com/'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT int he page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'sciendo.com-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'sciendo.com',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!content.sciendo.com!dgsg:dgsg2017!"provisional account"',
		'contact_groups' => 'admins_email_only,DGSG',
		'notes' => 'DGSG - Sciendo Fail Open',
		'notes_url' => 'https://content.sciendo.com/'
end
